#!/bin/bash --login
#PBS -o output_archer05.txt
#PBS -e error_archer05.txt
#PBS -N Barrier
#PBS -l select=3
#PBS -l walltime=4:00:00
#PBS -A e05-store-dar

SUFFIX=05
OUTPUT=output_archer${SUFFIX}.txt

export PBS_O_WORKDIR=$(readlink -f $PBS_O_WORKDIR)
cd $PBS_O_WORKDIR

module load vasp5
module load leave_time

if [[ -e ./OUTCAR ]] ;
then
  converged=$(grep -c 'reached required accuracy' ./OUTCAR);
  nsteps=$(grep -c aborting ./OUTCAR);
else
  converged=0
  nsteps=0;
fi

if (( $converged==0 || $nsteps!=1 )) ;
then
  echo ========================================================= >> $OUTPUT  
  echo PBS job: submitted  date = `date` >> $OUTPUT
  date_start=`date +%s` >> $OUTPUT
  echo >> $OUTPUT

  leave_time 60 aprun -n 72 -N 24 vasp5 >> ${OUTPUT} 2> error_archer${SUFFIX}.txt

  echo  >> $OUTPUT 
  echo --------------- >> $OUTPUT                                          
  echo Job output ends >> $OUTPUT                                          
  date_end=`date +%s`
  seconds=$((date_end-date_start))
  minutes=$((seconds/60))
  seconds=$((seconds-60*minutes))
  hours=$((minutes/60))
  minutes=$((minutes-60*hours))
  echo ========================================================= >> $OUTPUT
  echo PBS job: finished   date = `date` >> $OUTPUT
  echo Total run time : $hours Hours $minutes Minutes $seconds Seconds >> $OUTPUT
  echo =========================================================  >> $OUTPUT
  cp CONTCAR POSCAR
  mv XDATCAR XDATCAR${SUFFIX};
fi
